###DOmake.met.page.plots - creates 24hr profile ps plot file of INS data
##
## smsmith Mar96 mlvl62 - based on DOmake.imet.page.plot
## Modif Jun99 mlvl62 - Modified version of ins_met
## Modif Jan00 revelle - Correct spelling of Meteorological
## Modif Mar00 Melville - Change default range of precip and Longwave.
## Modif JSCharters Sep00 sdsioa - add gmtset command
## Modif DJ 2003jan06 because translator PC no longer feeds INS PC
##    (1) Set data dir from MET to TRANS: cd $DIRUWDATA/TRANS
##    (2) Replaced /usr/local/bin/ins/ins_met with perl program
##	    reading a TRANS/*.MET file
##    (3) Return is now yymmdd.MET:  set IFN = `$BINDIR/met_filename $DATE`
# Assumes environmental variables CRUISE, DIRUWDATA and BINDIR are set.

unset noclobber

if ($#argv < 1) then
   echo "usage: DOmake.met.page.plot   <date.ext>"
   echo " (produces profile ps file named metfile.<date.ext>.ps)"
   exit
endif

# Change these Lower/Upper ranges as necessary:

set AIRTEMP_RANGE = 15/40
set AIRTEMP_TIC = "a2g2f1:air temp (C.):"

set BARO_RANGE = 15/40
set BARO_TIC = "a10g5f5:Barometric pres (mm):"

set HUMI_RANGE = 15/40
set HUMI_TIC = "a10g5f5:Humidity (%):"

set PRIC_RANGE = 15/40
set PRIC_TIC = "a5g5f1:precipitation:"

set SHOR_RANGE = 15/40
set SHOR_TIC = "a100g200f50:Long Wave:"

set LONG_RANGE = 15/40
set LONG_TIC = "a100g200f10:Short Wave:"

# Don't change these:
set HR_RANGE       = 0./24.       ; set HR_TIC       = "2g1::"

# 
cd $DIRUWDATA/TRANS

gmtset ANOT_FONT_SIZE 10p HEADER_FONT_SIZE 16p LABEL_FONT_SIZE 12p

set DATE = $1

 set IFN = `$BINDIR/met_filename $DATE`

# test for a compressed file if exists then uncompress it
if ( -e $IFN.Z) then
	uncompress $IFN
endif

# test for the data file to exist
if !( -e $IFN) then
	echo "DOmake.met.page.plot: No data file: $IFN"
	exit
endif

# test if any data in file to process
grep '^\$' $IFN > /dev/null
#grep '^[0-9]' $IFN > /dev/null

if ( $status == 1) then
	compress -f $IFN
	exit
endif

###################################################

set PAGE_SIZE = letter

set OFN = MET.$IFN.ps

if ("$PAGE_SIZE" == "letter") then
   set XLENGTH = 6.5
   set YLENGTH = 1.1
   set XOFF1 = 1.2 ; set YOFF1 =  8.5
   set XOFF2 = 0.0 ; set YOFF2 = -1.5
   set OPT    = " -P "
else if ("$PAGE_SIZE" == "E") then
   echo E-size not done yet...
   exit
else 
   echo Should not be here with PAGE_SIZE of $PAGE_SIZE...
   exit
endif

set TITLE1   = "Meteorological Data $CRUISE  $DATE"
set TITLE2   = ""

set SIZE     = "$XLENGTH"/"$YLENGTH"
set SIZE_REV = "$XLENGTH"/-"$YLENGTH"
set AXES     = WeSn

/usr/local/bin/ins/ins_met < $IFN > all_data

###################### start the postscript file ############################
pwd | psxy -H1 >! $OFN -R0/1/0/1 -JX1/1 -X0 -Y0 -K `echo "$OPT"`


###################### start 1st panel ######################################
#
# First temp sensor

$BINDIR/met_ins_data.awk field=6 scale=2 all_data > 2col

set XOFF   = $XOFF1
set YOFF   = $YOFF1
set TITLE  = "$TITLE1"
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$AIRTEMP_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
set SYMB   = x0.05

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0

psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M -S"$SYMB"

psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
###################### end panel ############################################


###################### start 2nd panel ######################################

$BINDIR/met_ins_data.awk field=5 scale=10 all_data > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$BARO_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

###################### start 3nd panel ######################################

$BINDIR/met_ins_data.awk field=7 scale=10 all_data > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$HUMI_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

###################### start 4nd panel ######################################

$BINDIR/met_ins_data.awk field=9 scale=10 all_data > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$PRIC_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

###################### start 5nd panel ######################################

$BINDIR/met_ins_data.awk field=11 scale=10 all_data > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$SHOR_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

###################### start 6nd panel ######################################

$BINDIR/met_ins_data.awk field=10 scale=50 all_data > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$LONG_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

### finish off the postscript file ##########################################
pwd | psxy -H1 >> $OFN -R -JX -O `echo "$OPT"`
#
# Print the file
#
#lpr -Php8000 $OFN
lp -d hp8000 $OFN

#
# Remove the work files
#
#/bin/rm -f all_data range 2col
#compress files:
compress -f $IFN
#end
