#!/bin/perl -w
##############################################################
#File: grd2sd.pl
##############################################################
#Purpose: fledermaus sd file from netcdf grd file
#
# <Input> -d (debug)
#       -i (grid file input)
#       -o (output sd file name)
#       -h (help)
#       -c (pat hand file name to cmap)
# </Input>
#       NEED: make inf flag ( -inf  -c  -w ?)
#
# Relies On: mbsystems - unix tools
#
# <dependency time=20040229 21:20>
#       <object name=>
#        pwd, which, /bin/rm, mbinfo, mbm_grid
#       </object>
# </dependency>
#
##############################################################
#  GDC - SIO - UCDS - 2004
##############################################################
# <Author> Dru Clark </Author>
# <Date> 20040230 </Date>
# <Version> 1.0 </Version>
##############################################################
use strict;
use diagnostics;
use Getopt::Std;
##############################
# default values
my $debug = 0;

##############################
my $cmap_path = "/opt/Fledermaus/cmaps/";
#my $cmap_name = "land-sea.cmap";
my $cmap_name = "step32.cmap";
my $cmap = "$cmap_path$cmap_name";
##############################


my $prog_name = "grd2sd.pl";
my $NOT_SET = "not_set";
my $grdfile = $NOT_SET;
my $outfile = $NOT_SET;
my $format = "32";
my $make_inf = 0;
my $meter = "250"; #  default value
my $meter_resolution = "$meter/$meter";
##############################
my @lon;
my @lat;
##############################
my $cmd = "_mbgrid.cmd";
my $rm_cmd = "*.cmd";
my $grd = ".grd";
my $sd = ".sd";
my $inf = ".inf";
my $gridpath = "";
my $fledermauspath = "/opt/Fledermaus/bin";
my $pwd = `pwd`;
chomp $pwd;
##############################

     #################################
     #################################
     # read in command line arguments
     my %opts = ();
      getopts('i:c:dh', \%opts) || die &usage();

      ## -d
      if(exists($opts{'d'})){
           $debug = 1;
           print "<DEBUG> Debug mode on\n";
           print "<DEBUG> Working directory $pwd \n";
      }
      ## -h
      if(exists($opts{'h'})){
              &usage();
              exit();
      }
      ## -i
      if(exists($opts{'i'})){
              $grdfile = $opts{'i'};
      }
      else{
              &usage();
              die "ERROR: A grid file must be specified with -i: Exiting\n";
      }
      ## -c     test
      if(exists($opts{'c'})){

      }
      else{
               print "<DEBUG> Using Default cmap $cmap\n";
              #&usage();
              #die "ERROR: A cmap file must be specified with -i: Exiting\n";
      }
      #################################
      #################################

      # see if the mb file exists
      my $grd_test = &check_grd($grdfile);

      &run_grid($grdfile);

##############################################################
##############################################################
# SUBS
##############################################################
##############################################################

##############################################################
##############################################################
sub
check_grd()
{
     my $grd = shift(@_);

     if(-e "$grd") {
     		if($debug) {print "<DEBUG> GRID file exists: $grd \n";}
     return 1}
     else {
 		print "ERROR: GRD file does not exist: $grd \n";
		exit();
	  }
}
##############################################################
##############################################################
sub
run_grid()
{
  my $grd = shift(@_);

my $dtm = ".dtm";
my $geo = ".geo";
my $shade = ".shade";
my $sd = ".sd";
my $base_name = "./";
my $tmp_name = "tmp";
my $dtm_file = "$grd$dtm";
my $shade_file = "$grd$shade";
my $geo_file = "$grd$geo";

    if($debug) {print "<DEBUG> $fledermauspath/cmdop grdtoscalar -in $grd -out $grd $base_name -dtm -invert\n";}
    `$fledermauspath/cmdop grdtoscalar -in $grd -out $grd -dtm -invert`;
    `$fledermauspath/cmdop shade -dtm $dtm_file -cmap $cmap -out $shade_file`;
    `$fledermauspath/cmdop objectbuilder -t SonarDTM -out $grd$sd -in $dtm_file $shade_file $geo_file`;

    #`mv $base_name$sd $sdpath$mbfile$sd`;
    unlink "$dtm_file";
    unlink "$shade_file";
    unlink "$geo_file";

}
##############################################################
##############################################################
sub
usage()
{
	print "$prog_name Usage: -dhci \n";
	print "-d (debug) \n";
	print "-h (help) \n";
	print "-c <arg>(cmap path and name)\n";
        print "-i <arg>(mb file input)\n";
        print "Example: $prog_name -i <gridfile> -c ./global.cmap -d \n";

}
##############################################################
##############################################################
# END
