#!/usr/bin/perl
##############################################################################
#                                                                            #
#           Copyright by (c) Regents of the University of California         #
#                      University of California, San Diego                   #
#                      Scripps Institution of Oceanography                   #
#                           Shipboard Computer Group                         #
#                       La Jolla, California, USA 92093                      #
#                                                                            #
#                          All rights reserved. 2002                         #
#                                                                            #
#----------------------------------------------------------------------------#
#                                                                            #
# trim_ashtech_yesterday.pl                                                  #
#                                                                            #
# Written By: Steve Foley (foley@sdsioa.ucsd.edu)                            #
# Created:    Mon Jun  2 04:23:28 GMT 2003                                   #
#                                                                            #
# Purpose:                                                                   #
#                                                                            #
# This script trims out the first bit of an Ashtech column file (created     #
# during the script /SCG.PROC/sproc/bin/DOprocess_ashtech) that              #
# contains the last few minutes of the previous day's data. As a result,     #
# there is no mixup or end/start line drawing done when the data is          #
# plotted using GMT.                                                         #
#                                                                            #
# Usage:                                                                     #
#                                                                            #
# This script takes input on standard in and prints to standard out. It      #
# can be used like a normal unix pipeline command.                           #
# Input looks like:                                                          #
#  86174.000000 064.91 +002.56 -004.38                                       #
#  86175.000000 064.67 +004.67 -003.75                                       #
#                                                                            #
##############################################################################

# Start out assuming we are in a header that should be removed
my $in_header = true;
my $prev_value = 0;
my $first_line;

# Get one line for sanity checking
while (<>)
{
	$first_line = $_;
	($prev_value, @other) = split / /;
	last;
}

# if we arent in the last few minutes of a day, just process as usual
if ($prev_value < 86100)
{
	$in_header = false;
	print $first_line;
}


while (<>)
{
	# if we are done with the beginning, just print them all out
	if ($in_header eq false) { print "$_"; next; } 

        # actually search for the header start looking for an inflection pt.
	($value, @other) = split / /;
	if ($value < $prev_value)
	{
		$in_header = false;
		print $_;
	}
	$prev_value = $value;
}
